@@ -12,90 +12,8 @@ FrameType = Literal["video", "motion"]
 CameraType = Literal["camera", "doorbell"]
 ZoneType = Literal["intersect", "contain"]
 ZoneFilter = Literal["include", "exclude"]
-ObjectClass = Literal[
-    "person",
-    "bicycle",
-    "car",
-    "motorcycle",
-    "airplane",
-    "bus",
-    "train",
-    "truck",
-    "boat",
-    "traffic light",
-    "fire hydrant",
-    "stop sign",
-    "parking meter",
-    "bench",
-    "bird",
-    "cat",
-    "dog",
-    "horse",
-    "sheep",
-    "cow",
-    "elephant",
-    "bear",
-    "zebra",
-    "giraffe",
-    "backpack",
-    "umbrella",
-    "handbag",
-    "tie",
-    "suitcase",
-    "frisbee",
-    "skis",
-    "snowboard",
-    "sports ball",
-    "kite",
-    "baseball bat",
-    "baseball glove",
-    "skateboard",
-    "surfboard",
-    "tennis racket",
-    "bottle",
-    "wine glass",
-    "cup",
-    "fork",
-    "knife",
-    "spoon",
-    "bowl",
-    "banana",
-    "apple",
-    "sandwich",
-    "orange",
-    "broccoli",
-    "carrot",
-    "hot dog",
-    "pizza",
-    "donut",
-    "cake",
-    "chair",
-    "couch",
-    "potted plant",
-    "bed",
-    "dining table",
-    "toilet",
-    "tv",
-    "laptop",
-    "mouse",
-    "remote",
-    "keyboard",
-    "cell phone",
-    "microwave",
-    "oven",
-    "toaster",
-    "sink",
-    "refrigerator",
-    "book",
-    "clock",
-    "vase",
-    "scissors",
-    "teddy bear",
-    "hair drier",
-    "toothbrush",
-    "motion",
-]
-CameraRoles = Literal["high-resolution", "mid-resolution", "low-resolution", "snapshot"]
+ObjectClass = Literal["person", "vehicle", "animal", "motion", "other"]
+CameraRole = Literal["high-resolution", "mid-resolution", "low-resolution", "snapshot"]
 DecoderFormat = Literal["yuv420p", "rgb24", "nv12"]
 ImageInputFormat = Literal["yuv420p", "nv12", "rgb", "rgba", "gray"]
 ImageOutputFormat = Literal["rgb", "rgba", "gray"]
@@ -149,6 +67,7 @@ DeviceManagerEventType = Literal[
 JsonSchemaType = Literal["string", "number", "boolean", "object", "array", "button"]
 LoggerLevel = Literal["error", "warn", "info", "debug", "trace", "attention", "success"]
 APIEventType = Literal["finishLaunching", "shutdown"]
+InternalRole = Literal["AAC", "OPUS", "PCMA"]
 
 # Basic types
 Callback = Union[
@@ -199,6 +118,7 @@ class ZoneRegion(TypedDict):
     filter: ZoneFilter
     classes: list[ObjectClass]
     isPrivacyMask: bool
+    color: str
 
 
 class CameraZone(TypedDict):
@@ -213,6 +133,7 @@ class DetectionZone(TypedDict):
     filter: ZoneFilter
     classes: list[ObjectClass]
     isPrivacyMask: bool
+    color: str
 
 
 class MotionDetectionSettings(TypedDict):
@@ -237,9 +158,11 @@ class CameraFrameWorkerSettings(TypedDict):
 class CameraInput(TypedDict):
     _id: str
     name: str
-    roles: list[CameraRoles]
+    role: CameraRole
+    useForSnapshot: bool
+    hotMode: bool
     urls: "StreamUrls"
-    internal: bool
+    internal: Optional[InternalRole]
 
 
 class RTPInfo(TypedDict):
@@ -555,14 +478,18 @@ class VideoFrame(Protocol):
 class CameraInputSettings(TypedDict):
     _id: str
     name: str
-    roles: list[CameraRoles]
+    role: CameraRole
+    useForSnapshot: bool
+    hotMode: bool
     urls: list[str]
-    internal: bool
+    internal: Optional[InternalRole]
 
 
 class CameraConfigInputSettings(TypedDict):
     name: str
-    roles: list[CameraRoles]
+    role: CameraRole
+    useForSnapshot: bool
+    hotMode: bool
     urls: list[str]
 
 
@@ -602,9 +529,11 @@ class CameraBaseSource(Protocol):
     # from CameraInput
     id: str  # _id
     name: str
-    roles: list[CameraRoles]
+    role: CameraRole
+    useForSnapshot: bool
+    hotMode: bool
     urls: StreamUrls
-    internal: bool
+    internal: Optional[InternalRole]
     # end CameraInput
 
     async def snapshot(self, force_new: Optional[bool] = None) -> Optional[bytes]: ...
@@ -613,13 +542,13 @@ class CameraBaseSource(Protocol):
         self, probe_config: Optional[ProbeConfig] = None, refresh: Optional[bool] = None
     ) -> Optional[ProbeStream]: ...
 
+    def create_webrtc_session(self) -> None: ...
+    def create_rtsp_session(self) -> None: ...
+    def create_fmp4_session(self) -> None: ...
+
 
 class CameraDeviceSource(CameraBaseSource, Protocol):
-    def get_internal_source(self, type: InternalSourceType) -> "CameraDeviceInternalSource": ...
-
-
-class CameraDeviceInternalSource(CameraBaseSource, Protocol):
-    type: InternalSourceType
+    def get_internal_source(self, type: InternalSourceType) -> "CameraBaseSource": ...
 
 
 class WebRTCConnectionOptions(TypedDict, total=False):
@@ -718,7 +647,9 @@ class CameraPropertyObservableObject(TypedDict):
 class CameraConfigInputSettingsPartial(TypedDict, total=False):
     # _id: str
     name: str
-    roles: list[CameraRoles]
+    role: CameraRole
+    useForSnapshot: bool
+    hotMode: bool
     urls: list[str]
 
 
@@ -777,13 +708,13 @@ class CameraDevice(Protocol):
     @property
     def low_resolution_source(self) -> Optional[CameraDeviceSource]: ...
     @property
-    def snapshot_source(self) -> Optional[CameraInput]: ...
+    def snapshot_source(self) -> Optional[CameraBaseSource]: ...
     @property
     def ptz(self) -> CameraPTZDelegate: ...
     @property
     def sources(self) -> list[CameraDeviceSource]: ...
     @property
-    def internal_sources(self) -> list[CameraDeviceInternalSource]: ...
+    def internal_sources(self) -> list[CameraBaseSource]: ...
 
     on_connected: HybridObservable[bool]
     on_frameworker_connected: HybridObservable[bool]
